# Contents

A software package to run ensemble data assimilation and parameter estimation experiments with the EAKF and LETKF.

## General-purpose code
* Module `ENDA.py`: Data assimilation code. Includes implementations of the EAKF and the LETKF. Also includes classes for data assimilation cycles, diagnostics and experiments (nature run + cycle + diagnostics).

## Basic parameter estimation code
These were used in a manuscript on parameter estimation for a convective boundary layer parameterization scheme (single-column model, SCM):
* Script `PE_CBL.py`: Main code.
* Module `PE_CBL_models.py`: Classes and functions for the SCM intialization and integration
* Module `PE_CBL_graphics.py`: Functions to plot results.
* A set of `*tar.gz` archives, containing `.json` configuration files for the parameter estimation experiments.

## Other code (`utils` folder)
* Module `observations.py`: Code to ingest external observations (e.g. from an LES model, or actual observations) in parameter estimation experiments.
* Module `verification.py`: Code to verify experiments against external observations.
* Script `replace_text.py`: A tool to edit a set of similar config files all at once.

## Other
* Notebook `Overview.ipynb`: Simple usage examples. Much more exhaustive examples are provided in `PE_CBL.py`.

## Dependencies
The code depends on `numpy`, `scipy`, `matplotlib`, `json`, `pandas`, `pickle`, `os`, `glob`